@@ -10,7 +10,6 @@ import pymongo
 from scout.build.case import build_case
 from scout.constants import ACMG_MAP
 from scout.exceptions import ConfigError, IntegrityError
-from scout.parse.case import parse_case
 from scout.parse.variant.ids import parse_document_id
 from scout.utils.algorithms import ui_score
 
@@ -169,12 +168,16 @@ class CaseHandler(object):
 
         if query_field == "exact_pheno":
             if query_term != "":
-                query["phenotype_terms.phenotype_id"] = query_term
+                # User might have provided multiple query terms
+                query["phenotype_terms.phenotype_id"] = {
+                    "$in": [term for term in query_term.replace(" ", "").split(",")]
+                }
             else:  # query for cases with no HPO terms
                 query["$or"] = [
                     {"phenotype_terms": {"$size": 0}},
                     {"phenotype_terms": {"$exists": False}},
                 ]
+
         if query_field == "synopsis":
             if query_term != "":
                 query["$text"] = {"$search": query_term}
@@ -632,10 +635,8 @@ class CaseHandler(object):
         institute_obj = self.institute(config_data["owner"])
         if not institute_obj:
             raise IntegrityError("Institute '%s' does not exist in database" % config_data["owner"])
-        # Parse the case information
-        parsed_case = parse_case(config=config_data)
         # Build the case object
-        case_obj = build_case(parsed_case, self)
+        case_obj = build_case(config_data, self)
         # Check if case exists with old case id
         old_caseid = "-".join([case_obj["owner"], case_obj["display_name"]])
         old_case = self.case(old_caseid)
@@ -643,7 +644,7 @@ class CaseHandler(object):
         # This is to keep sanger order and validation status
         old_sanger_variants = self.case_sanger_variants(case_obj["_id"])
 
-        genome_build = str(parsed_case.get("genome_build", 37))
+        genome_build = str(config_data.get("genome_build", 37))
 
         if old_case:
             LOG.info(
