@@ -3,16 +3,7 @@ import logging
 import os.path
 
 import requests
-from flask import (
-    Blueprint,
-    Response,
-    abort,
-    current_app,
-    flash,
-    render_template,
-    request,
-    send_file,
-)
+from flask import Blueprint, Response, abort, render_template, request, send_file
 
 from . import controllers
 from .partial import send_file_partial
@@ -67,7 +58,7 @@ def remote_cors(remote_url):
 @alignviewers_bp.route("/remote/static", methods=["OPTIONS", "GET"])
 def remote_static():
     """Stream *large* static files with special requirements."""
-    file_path = request.args.get("file")
+    file_path = request.args.get("file") or ""
     range_header = request.headers.get("Range", None)
     if not range_header and (file_path.endswith(".bam") or file_path.endswith(".cram")):
         return abort(500)
