@@ -50,6 +50,9 @@ def gene(hgnc_id=None, hgnc_symbol=None):
 def api_genes():
     """Return JSON data about genes."""
     query = request.args.get("query")
-    build = request.args.get("build", "all")
+    if query is None or query.replace("-", "").isalnum() is False:
+        return jsonify({"code": 400, "message": "missing or invalid 'query' param in request"})
+    build = request.args.get("build", "37")
+
     json_out = controllers.genes_to_json(store, query, build)
     return jsonify(json_out)
