@@ -1,12 +1,13 @@
 """Common utilities for the server code"""
 import datetime
-import io
 import logging
 import os
 import pathlib
 import zipfile
 from functools import wraps
+from io import BytesIO
 
+import pdfkit
 from bson.objectid import ObjectId
 from flask import abort, flash, render_template, request
 from flask_login import current_user
@@ -14,6 +15,28 @@ from flask_login import current_user
 LOG = logging.getLogger(__name__)
 
 
+def html_to_pdf_file(html_string, orientation, dpi=96):
+    """Creates a pdf file from the content of an HTML file
+    Args:
+        html_string(string): an HTML string to be rendered as PDF
+        orientation(string): landscape, portrait
+        dpi(int): dot density of the page to be printed
+
+    Returns:
+        bytes_file(BytesIO): a BytesIO file
+    """
+    options = {
+        "page-size": "A4",
+        "orientation": orientation,
+        "encoding": "UTF-8",
+        "dpi": dpi,
+        "enable-local-file-access": None,
+    }
+    pdf = pdfkit.from_string(html_string, False, options=options, verbose=True)
+    bytes_file = BytesIO(pdf)
+    return bytes_file
+
+
 def jsonconverter(obj):
     """Converts non-serializable onjects into str"""
     LOG.warning(f"An object of type {type(obj)} is not json-serializable: converting it.")
@@ -223,7 +246,7 @@ def zip_dir_to_obj(path):
         data(io.BytesIO): zipped data object
     """
 
-    data = io.BytesIO()
+    data = BytesIO()
     with zipfile.ZipFile(data, mode="w") as z:
         for f_name in pathlib.Path(path).iterdir():
             z.write(f_name, os.path.basename(f_name))
